#pragma once

#include <QFile>
#include <QHash>
#include <QStack>

class Device {
private:
    struct Interface {
        QString interface;
        QString interfaceName;
    };

    struct Product {
        QString product;
        QString productName;
        QStack<Interface> interfaces;
    };

    struct Vendor {
        QString vendorName;
        QStack<Product> products;
    };

    // Interface protocol
    struct IProtocol {
        QString iprotocol;
        QString iprotocolName;
    };

    // Interface subclass
    struct ISubclass {
        QString isubclass;
        QString isubclassName;
        QStack<IProtocol> iprotocols;
    };

    // Interface class
    struct IClass {
        QString iclassName;
        QStack<ISubclass> isubclasses;
    };

    QHash<QString, Vendor> _devData;
    QHash<QString, IClass> _interfaceData;

public:
    Device(QString);

    QPair<QString, QString> getDevice(QString) const;
    QPair<QString, QString> getInterface(QString) const;

private:
    void parseData(QString);
    void parseDevData(QFile&, QString, QString, bool);
    void parseInterfaceData(QFile&, QString, QString, bool);
};
